
# Slot: subclass of


holds between two classes where the domain class is a specialization of the range class

URI: [biolink:subclass_of](https://w3id.org/biolink/vocab/subclass_of)


## Domain and Range

[OntologyClass](OntologyClass.md) &#8594;  <sub>0..\*</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [organism taxon➞subclass of](organism_taxon_subclass_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | rdfs:subClassOf |
|  | | SEMMEDDB:IS_A |
|  | | SEMMEDDB:isa |
|  | | WIKIDATA_PROPERTY:P279 |
|  | | CHEMBL.MECHANISM:subset_of |
|  | | GO:isa |
|  | | MESH:isa |
|  | | RTXKG1:subclass_of |
|  | | RXNORM:isa |
|  | | VANDF:isa |
| **Close Mappings:** | | LOINC:class_of |
|  | | LOINC:has_class |
| **Narrow Mappings:** | | CHEBI:has_parent_hydride |
|  | | LOINC:has_archetype |
|  | | LOINC:has_parent_group |
|  | | LOINC:is_presence_guidance_for |
|  | | NCIT:gene_product_has_chemical_classification |
|  | | NCIT:R36 |
|  | | NCIT:R42 |
|  | | NCIT:A16 |
|  | | NCIT:A11 |
|  | | NCIT:A14 |
|  | | NCIT:A3 |
|  | | NDDF:has_dose_form |
|  | | OBO:intersection_of |
|  | | RXNORM:has_dose_form |
|  | | RXNORM:has_doseformgroup |
|  | | SNOMED:entire_anatomy_structure_of |
|  | | SNOMED:has_dose_form |
|  | | rdfs:subPropertyOf |

